﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Experior.Core;
using Experior.Core.Communication;
using Experior.Core.Communication.PLC;
using Experior.Catalog.Logistic.Sensor;


namespace Experior.Plugin
{
    public partial class frmSensorIO : Experior.Core.Forms.Form
    {
        private List<SensorIOGridItem> sensorIOs;

        public frmSensorIO()
        {
            InitializeComponent();
            this.Text = "Imported sensor outputs";
            sensorIOs = new List<SensorIOGridItem>();
        }

        public override Core.Forms.Docking.DockContent.FormTypes FormType
        {
            get
            {
                return Core.Forms.Docking.DockContent.FormTypes.Permanent;
            }
        }
        public void startLoading()
        {
            sensorIOs.Clear();
            Invoke(new MethodInvoker(RefreshDataGrid));

            System.Threading.Thread thr = new System.Threading.Thread(new System.Threading.ThreadStart(LoadSensors));
            thr.Start();
        }

        private void LoadSensors()
        {
            foreach (Experior.Core.Assemblies.Assembly asm in Experior.Core.Assemblies.Assembly.Items.Values)
            {
                if (asm is Experior.Catalog.Logistic.Sensor.BaseSensor)
                {
                    BaseSensor bs = asm as BaseSensor;
                    SensorInfo si = (SensorInfo)bs.Info;
                    if (si.outputblocked != null)
                    {
                        Output o = si.outputblocked;
                        SensorIOGridItem item = new SensorIOGridItem();
                        item.Bit = o.BitNo.ToString();
                        item.Byte = o.ByteNo.ToString();
                        item.Name = o.Symbol;
                        item.Description = o.Description;
                        if (o.Connection != null)
                            item.Connection = o.Connection.Name;
                        else item.Connection = "None";
                        item.Value = o.Value.ToString();
                        // add it to the datasource of the datagrid
                        sensorIOs.Add(item);
                    }
                }
            }
            Invoke(new MethodInvoker(RefreshDataGrid));
        }
        private void refreshToolStripMenuItem_Click(object sender, EventArgs e)
        {
            RefreshDataGrid();
        }
        public void RefreshDataGrid()
        {
            dataGridView1.Refresh();
            dataGridView1.Parent.Refresh();

            BindingSource binding = new BindingSource();
            binding.DataSource = sensorIOs;
            dataGridView1.DataSource = binding;
        }
        public new void Hide()
        {
            Invoke(new MethodInvoker(base.Hide));
        }


        internal class SensorIOGridItem
        {
            public SensorIOGridItem() { }

            public string Name { get; set; }
            public string Connection { get; set; }
            public string Byte { get; set; }
            public string Bit { get; set; }
            public string Value { get; set; }
            public string Description { get; set; }
        }
    }
}
